###############################################################################
###############################################################################
##
##  Copyright (C) 2004-2008 Red Hat, Inc.  All rights reserved.
##
##  This copyrighted material is made available to anyone wishing to use,
##  modify, copy, or redistribute it subject to the terms and conditions
##  of the GNU General Public License v.2.
##
###############################################################################
###############################################################################

# main (empty) package
# http://www.rpm.org/max-rpm/s1-rpm-subpack-spec-file-changes.html

# keep around ready for later user
# %%define alphatag 2.99.02

Name: cluster
Summary: Red Hat Cluster
Version: 2.99.12
Release: 1%{?alphatag:.%{alphatag}}%{?dist}
License: GPLv2+ and LGPLv2+
Group: System Environment/Base
URL: http://sources.redhat.com/cluster/wiki/
Source0: ftp://sources.redhat.com/pub/cluster/releases/cluster-%{version}.tar.gz

## Setup/build bits

# build support for virtualization
%define buildvirt 0
%ifarch i386 x86_64 ia64
%define buildvirt 1
%endif

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Build dependencies
BuildRequires: perl python
BuildRequires: glibc-kernheaders glibc-devel
BuildRequires: libxml2-devel ncurses-devel slang-devel libvolume_id-devel
BuildRequires: corosync-devel >= 0.92 corosync-devel < 0.93
BuildRequires: openais-devel >= 0.91 openais < 0.92
BuildRequires: openldap-devel perl(ExtUtils::MakeMaker)
%if %{buildvirt}
BuildRequires: nss-devel nspr-devel libvirt-devel xen-libs
%endif

%prep
%setup -q -n cluster-%{version}

%build
# for legacy reasons, all binaries have always been installed in /sbin
./configure \
  --sbindir=/sbin \
  --initddir=%{_sysconfdir}/rc.d/init.d \
  --libdir=%{_libdir} \
%if %{buildvirt}
  --enable_virt \
%endif
  --corosynclibdir=%{_libdir}/corosync \
  --openaislibdir=%{_libdir}/openais \
  --without_kernel_modules \
  --disable_kernel_check

##CFLAGS="$(echo '%{optflags}')" make %{_smp_mflags}
CFLAGS="$(echo '%{optflags}')" make

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/cluster
# install logging bits
mkdir -p $RPM_BUILD_ROOT/var/log/cluster

## tree fix up
# logrotate name
mv $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/cluster \
	$RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/cman
# remove static libraries
find $RPM_BUILD_ROOT -name "*.a" -exec rm {} \;
# fix library permissions or fedora strip helpers won't work.
find $RPM_BUILD_ROOT -name "lib*.so.*" -exec chmod 0755 {} \;
# fix lcrso permissions or fedora strip helpers won't work.
find $RPM_BUILD_ROOT -name "*.lcrso" -exec chmod 0755 {} \;
# fix libfence permissions
chmod 0755 $RPM_BUILD_ROOT%{_datadir}/fence/*.py
chmod 0755 $RPM_BUILD_ROOT%{_datadir}/fence/telnet_ssl
# remove docs
rm -rf $RPM_BUILD_ROOT/usr/share/doc/cluster
# cleanup perl bindings bits
find $RPM_BUILD_ROOT -type f -name .packlist -exec rm -f {} \;
find $RPM_BUILD_ROOT -type f -name perllocal.pod -exec rm -f {} \;
find $RPM_BUILD_ROOT -type f -name '*.bs' -a -empty -exec rm -f {} \;
find $RPM_BUILD_ROOT -type f -name CCS.so -exec chmod 755 {} \;

%clean
rm -rf $RPM_BUILD_ROOT

## Runtime and subpackages section

# main empty package
%description
Red Hat Cluster

## subpackages

%package -n cman
Group: System Environment/Base
Summary: Red Hat Cluster Manager
Requires(post): chkconfig
Requires(preun): initscripts
Requires(preun): chkconfig
Requires: corosync >= 0.92 corosync < 0.93
Requires: openais >= 0.91 openais < 0.92
Requires: sg3_utils OpenIPMI telnet openssh-clients
Requires: pexpect net-snmp-utils pyOpenSSL
Requires: perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires: ricci >= 0.15.0-4 modcluster >= 0.15.0-3

%description -n cman
Red Hat Cluster Manager

%post -n cman
/sbin/chkconfig --add cman
/sbin/chkconfig --add scsi_reserve
/sbin/chkconfig --add qdiskd
/sbin/ldconfig > /dev/null

# make sure to stop cman always as last
%preun -n cman
if [ "$1" = 0 ]; then
	/sbin/service qdiskd stop >/dev/null 2>&1
	/sbin/service scsi_reserve stop >/dev/null 2>&1
	/sbin/service cman stop >/dev/null 2>&1
	/sbin/chkconfig --del qdiskd
	/sbin/chkconfig --del scsi_reserve
	/sbin/chkconfig --del cman
fi

%postun -n cman -p /sbin/ldconfig

%files -n cman
%defattr(-,root,root,-)
%doc doc/COPYING.* doc/COPYRIGHT doc/README.licence doc/*.txt config/plugins/ldap/*.ldif
%dir %{_sysconfdir}/cluster
%{_sysconfdir}/rc.d/init.d/cman
%{_sysconfdir}/rc.d/init.d/qdiskd
%{_sysconfdir}/rc.d/init.d/scsi_reserve
%config(noreplace) %{_sysconfdir}/udev/rules.d/*-dlm.rules
%config(noreplace) %{_sysconfdir}/logrotate.d/cman
/sbin/ccs*
/sbin/cman*
/sbin/confdb2ldif
/sbin/dlm*
/sbin/fence*
/sbin/gfs_control*
/sbin/group*
/sbin/*qdisk*
%{_libdir}/libccs*.so.*
%{_libdir}/libdlm*.so.*
%{_libdir}/libfence*.so.*
%{_libdir}/liblogthread*.so.*
%{_datadir}/fence*
%{_datadir}/snmp/mibs/*
/usr/libexec/*
%{perl_vendorarch}/*
%dir /var/log/cluster
%{_mandir}/man5/*
%{_mandir}/man7/*
%{_mandir}/man8/ccs*
%{_mandir}/man8/cman*
%{_mandir}/man8/confdb2ldif*
%{_mandir}/man8/dlm*
%{_mandir}/man8/fence*
%{_mandir}/man8/gfs_control*
%{_mandir}/man8/group*
%{_mandir}/man8/*qdisk*
%{_mandir}/man3/*.3pm.gz

%package -n cman-devel
Group: Development/Libraries
Summary: The Cluster Manager development package
Requires: cman = %{version}-%{release}

%files -n cman-devel
%defattr(-,root,root,-)
%{_libdir}/libccs*.so
%{_libdir}/libdlm*.so
%{_libdir}/libfence*.so
%{_libdir}/liblogthread*.so
%{_includedir}/ccs.h
%{_includedir}/libdlm*.h
%{_includedir}/libfence.h
%{_includedir}/liblogthread.h
%{_mandir}/man3/*3.gz

%description -n cman-devel
The Cluster Manager development package

%package -n cmanlib
Group: System Environment/Libraries
Summary: The Cluster Manager library
Conflicts: cman <= 2.99.10-3

%files -n cmanlib
%defattr(-,root,root,-)
%{_libdir}/libcman.so.*

%description -n cmanlib
The Cluster Manager library package

%post -n cmanlib -p /sbin/ldconfig

%postun -n cmanlib -p /sbin/ldconfig

%package -n cmanlib-devel
Group: Development/Libraries
Summary: The Cluster Manager library development package
Conflicts: cman-devel <= 2.99.10-3
Requires: cmanlib = %{version}-%{release}

%files -n cmanlib-devel
%defattr(-,root,root,-)
%{_includedir}/libcman.h
%{_libdir}/libcman.so

%description -n cmanlib-devel
The Cluster Manager library development package

%package -n rgmanager
Group: System Environment/Base
Summary: Open Source HA Resource Group Failover for Red Hat Cluster
License: GPLv2+ and LGPLv2+
Requires: chkconfig initscripts glibc ncurses bash grep sed gawk
Requires: cman
Requires: net-tools mount e2fsprogs
Requires(post): chkconfig
Requires(preun): initscripts
Requires(preun): chkconfig

%description -n rgmanager
Red Hat Resource Group Manager provides high availability of critical server
applications in the event of planned or unplanned system downtime.

%post -n rgmanager
/sbin/chkconfig --add rgmanager

%preun -n rgmanager
if [ "$1" = 0 ]; then
	/sbin/service rgmanager stop >/dev/null 2>&1
	/sbin/chkconfig --del rgmanager
fi

%files -n rgmanager
%defattr(-,root,root,-)
%doc doc/COPYING.* doc/COPYRIGHT doc/README.licence rgmanager/README rgmanager/errors.txt
%{_sysconfdir}/rc.d/init.d/rgmanager
/sbin/clu*
/sbin/rg_test
%{_datadir}/cluster
%{_mandir}/man8/clu*

%package -n gfs2-utils
Group: System Environment/Kernel
Summary: Utilities for managing the global filesystem (GFS2)
Requires(post): chkconfig
Requires(preun): initscripts
Requires(preun): chkconfig

%description -n gfs2-utils
The gfs2-utils package contains a number of utilities for creating,
checking, modifying, and correcting any inconsistencies in GFS2
filesystems.

%post -n gfs2-utils
/sbin/chkconfig --add gfs2

%preun -n gfs2-utils
if [ "$1" = 0 ]; then
	/sbin/service gfs2 stop >/dev/null 2>&1
	/sbin/chkconfig --del gfs2
fi

%files -n gfs2-utils
%defattr(-,root,root,-)
%doc doc/COPYRIGHT doc/README.licence doc/COPYING.*
%{_sysconfdir}/rc.d/init.d/gfs2
/sbin/*gfs2*
%{_mandir}/man8/*gfs2*

%package -n gfs-utils
Group: System Environment/Kernel
Summary: Utilities for managing the global filesystem (GFS)
Requires(post): chkconfig
Requires(preun): initscripts
Requires(preun): chkconfig
Requires: gfs2-utils

%description -n gfs-utils
The gfs-utils package contains a number of utilities for creating,
checking, modifying, and correcting any inconsistencies in GFS
filesystems. This package requires the GFS kernel module.

%post -n gfs-utils
/sbin/chkconfig --add gfs

%preun -n gfs-utils
if [ "$1" = 0 ]; then
	/sbin/service gfs stop >/dev/null 2>&1
	/sbin/chkconfig --del gfs2
fi

%files -n gfs-utils
%defattr(-,root,root,-)
%doc doc/COPYRIGHT doc/README.licence doc/COPYING.*
%{_sysconfdir}/rc.d/init.d/gfs
/sbin/gfs_*
/sbin/*.gfs
%{_mandir}/man8/gfs.*
%{_mandir}/man8/gfs_*

%package -n gnbd-utils
Group: System Environment/Kernel
Summary: Utilities for managing the GFS Network Block Device
Requires(post): chkconfig
Requires(preun): initscripts
Requires(preun): chkconfig

%description -n gnbd-utils
The gnbd-utils package contains a number of utilities for exporting,
importing and managing GFS Network Block Devices.
This package requires the GNBD kernel module.

%files -n gnbd-utils
%defattr(-,root,root,-)
%doc doc/COPYRIGHT doc/README.licence doc/COPYING.*
# %%{_sysconfdir}/rc.d/init.d/gfs
/sbin/gnbd_*
%{_mandir}/man8/gnbd*

%changelog
* Mon Nov  3 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.12-1
- new upstream release.
  Fix several security related issues.

* Mon Oct 20 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.11-1
- new upstream release.
- drop obsoleted patches.
- include very important gfs1 bug fix.
- include fix for fence_egenera (CVE-2008-4192).

* Wed Oct  8 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.10-6
- cman init: add fix from upstream for cman_tool wrong path.

* Fri Sep 26 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.10-5
- cman now Requires: ricci and modcluster.

* Fri Sep 26 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.10-4
- Split libcman.so* from cman and cman-devel into  cmanlib and cmanlib-devel
  to break a very annoying circular dependency.

* Thu Sep 25 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.10-3
- The "CVS HATES ME" release.
- New upstream release.
- Build against new corosync and openais.
- specfile cleanup: rename buildxen to buildvirt.

* Thu Sep 25 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.10-2
- Retag release.
- New upstream release.
- Build against new corosync and openais.
- specfile cleanup: rename buildxen to buildvirt.

* Thu Sep 25 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.10-1
- New upstream release.
- Build against new corosync and openais.
- specfile cleanup: rename buildxen to buildvirt.

* Wed Sep 03 2008 Jesse Keating <jkeating@redhat.com> - 2.99.08-3
- Rebuild for broken deps.
- Pull in upstream patches for libvolume_id changes

* Wed Sep 03 2008 Jesse Keating <jkeating@redhat.com> - 2.99.08-2
- Rebuild for broken deps.

* Tue Aug 12 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.08-1
- New upstream release.
- Drop local patch that's part of upstream.
- Tight BR and Requires for openais to a very specific version.
- cman Requires ricci as new default config distribution system.
  (ricci changes will land soon but in the meantime this is done our side)

* Fri Aug  1 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.07-1
- New upstream release.
- Add patch to build against new headers (already part of upstream next release)
- BR on perl(ExtUtils::MakeMaker) to build perl bindings
- Fix logrotate install from upstream
- Add "clean up after perl bindings" snippet
- Update Requires for perl bindings
- Properly split man3 man pages

* Tue Jul 15 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.06-1
- New upstream release.
- BR on new openais for logging features.
- drop local logrotate snippet in favour of upstream one.
- cman Requires: PyOpenSSL for telnet_ssl wrapper.
- cman Requires: pexpect and net-snmp-utils for fence agents.
  Thanks to sendro on IRC for spotting the issue.
- Another cleanup round for docs

* Tue Jun 24 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.05-1
- New upstream release
- Update licence tags again after upstream relicensing to kill OSL 2.1.
- Add 2 commodity packages (gfs-utils and gnbd-utils). They both
  require external kernel modules but at least userland will stay
  automatically in sync for our users.
- BR openais 0.84 for new logsys symbols (and requires for runtime).
- Update build section to enable gfs-utils and gnbd-utils.

* Mon Jun  9 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.04-1
- New upstream release
- Update license tags after major upstream cleanup (note: rgmanager
  includes a shell script that is shipped under OSL 2.1 license).
- Update inclusion of documents to reflect updated COPYRIGHT file
  from upstream.
- Add documentation to different packages.

* Mon Jun  2 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.03-1
- New upstream release
- cman Requires telnet and ssh client
- drops some tree fix up bits that are now upstream

* Fri May 23 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.02-4
- Add missing OpenIPMI requires to cman for fence_ipmilan

* Thu May 22 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.02-3
- New kernel-headers has what we need release.
- Drop BR on kernel-devel.
- Drop cluster-dlmheaders.patch.
- Drop --kernel_* from configure invokation.
- Cleanup a few comments in the spec file.

* Tue May 20 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.02-2
- disable parallel build (broken upstream)
- build requires higher openais (fix ppc64 build failure)

* Mon May 19 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.02-1
- New upstream release
- Shut up the last few rpmlint warnings

* Wed May 15 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.01-4
- Fix typo in rgmanager Summary

* Wed May 14 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.01-3
- Fix rgmanager License: tag.

* Wed May 14 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.01-2
- Drop BR on openais as it is pulled by openais-devel.
- Change postun section to use -p /sbin/ldconfig.
- Fix rgmanager Requires.

* Wed May 14 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.99.01-1
- Initial packaging.
